@@ -405,7 +405,7 @@ func (p *pageState) setMetaPostParams() error {
 	}
 
 	var gitAuthorDate time.Time
-	if !p.gitInfo.IsZero() {
+	if p.gitInfo != nil {
 		gitAuthorDate = p.gitInfo.AuthorDate
 	}
 
@@ -675,7 +675,7 @@ params:
 
 	params["iscjklanguage"] = pcfg.IsCJKLanguage
 
-	if err := pcfg.Validate(false); err != nil {
+	if err := pcfg.Init(false); err != nil {
 		return err
 	}
 
